@@ -1,10 +1,10 @@
 
 # Imports
-from ..utils.print import *
-from ..utils.io import *
+import stouputils as stp
+from ..utils.io import write_to_file, write_to_function, FILES_TO_WRITE
 
 
-@measure_time(info, "Custom blocks ticks and second functions calls")
+@stp.measure_time(stp.info, "Custom blocks ticks and second functions calls")
 def custom_blocks_ticks_and_second_functions(config: dict) -> None:
 	""" Setup custom blocks ticks and second functions calls\n
 	It will seek for "second.mcfunction" and "tick.mcfunction" files in the custom_blocks folder\n
